window.Gleam.initSearch([{"doc":"plunk","title":"plunk","content":"# plunk\n\n[![Package Version](https://img.shields.io/hexpm/v/plunk)](https://hex.pm/packages/plunk)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/plunk/)\n\n## Installation\n\nThis library has been designed to be independent of whatever HTTP request library or runtime you choose or wish to use, and you can install for all targets by running:\n\n```sh\ngleam add plunk\n```\n\n## Usage\n\n```rust\nimport gleam/erlang/os\nimport gleam/io\nimport gleam/json\nimport gleam/result\nimport gleam/hackney\nimport plunk\nimport plunk/event.{Event}\n\npub fn main() {\n  let key =\n    os.get_env(&quot;PLUNK_API_KEY&quot;)\n    |&gt; result.unwrap(&quot;&quot;)\n\n  let assert Ok(resp) =\n    plunk.new(key)\n    |&gt; event.track(Event(\n      event: &quot;your-event&quot;,\n      email: &quot;someone@example.com&quot;,\n      data: [#(&quot;name&quot;, json.string(&quot;John&quot;))],\n    ))\n    |&gt; hackney.send\n\n  let assert Ok(e) = event.decode(resp)\n  io.debug(e)\n}\n```\n\nSee [documentation](https://hexdocs.pm/plunk/) for each module on Hexdocs or go through the [test](./test/) folder for examples.\n\n## Development\n\nTo run tests locally, you need to add your Plunk API key to the environment variables like this:\n\n```sh\nexport PLUNK_API_KEY=&quot;sk_...&quot;\n```\n\n&gt; NOTE: tests are designed to run only in the BEAM runtime (erlang target) as they depend on hackney\n","url":"index.html"},{"doc":"plunk/instance","title":"Instance","content":"pub type Instance {\n  Instance(api_key: String)\n}\n\nInstance(api_key: String)\n\n\nSynonyms:\nplunk/instance.Instance\nplunk/instance Instance","url":"plunk/instance.html#Instance"},{"doc":"plunk/instance","title":"plunk/instance","content":"","url":"plunk/instance.html"},{"doc":"plunk/types","title":"PlunkError","content":"pub type PlunkError {\n  ApiError(code: Int, error: String, message: String, time: Int)\n  JSONError(json.DecodeError)\n}\n\nApiError(code: Int, error: String, message: String, time: Int)\n Error returned directly from the Plunk API\n\nJSONError(json.DecodeError)\n Errors from the Gleam JSON library\n\nSynonyms:\nplunk/types.PlunkError\nplunk/types PlunkError","url":"plunk/types.html#PlunkError"},{"doc":"plunk/types","title":"plunk/types","content":"","url":"plunk/types.html"},{"doc":"plunk/transactional","title":"Contact","content":"pub type Contact {\n  Contact(id: String, email: String)\n}\n\nContact(id: String, email: String)\n\n\nSynonyms:\nplunk/transactional.Contact\nplunk/transactional Contact","url":"plunk/transactional.html#Contact"},{"doc":"plunk/transactional","title":"Email","content":"pub type Email {\n  Email(contact: Contact, email: String)\n}\n\nEmail(contact: Contact, email: String)\n\n\nSynonyms:\nplunk/transactional.Email\nplunk/transactional Email","url":"plunk/transactional.html#Email"},{"doc":"plunk/transactional","title":"SendTransactionalEmailResponse","content":"pub type SendTransactionalEmailResponse {\n  SendTransactionalEmailResponse(\n    success: Bool,\n    emails: List(Email),\n    timestamp: Option(String),\n  )\n}\n\nSendTransactionalEmailResponse(\n  success: Bool,\n  emails: List(Email),\n  timestamp: Option(String),\n)\n\n\nSynonyms:\nplunk/transactional.SendTransactionalEmailResponse\nplunk/transactional SendTransactionalEmailResponse","url":"plunk/transactional.html#SendTransactionalEmailResponse"},{"doc":"plunk/transactional","title":"To","content":"pub type To {\n  Address(String)\n  Addresses(List(String))\n}\n\nAddress(String)\n\n\nAddresses(List(String))\n\n\nSynonyms:\nplunk/transactional.To\nplunk/transactional To","url":"plunk/transactional.html#To"},{"doc":"plunk/transactional","title":"TransactionalEmail","content":"pub type TransactionalEmail {\n  TransactionalEmail(\n    to: To,\n    subject: String,\n    body: String,\n    name: Option(String),\n    from: Option(String),\n  )\n}\n\nTransactionalEmail(\n  to: To,\n  subject: String,\n  body: String,\n  name: Option(String),\n  from: Option(String),\n)\n\n\nSynonyms:\nplunk/transactional.TransactionalEmail\nplunk/transactional TransactionalEmail","url":"plunk/transactional.html#TransactionalEmail"},{"doc":"plunk/transactional","title":"decode","content":"pub fn decode(res: Response(String)) -&gt; Result(\n  SendTransactionalEmailResponse,\n  PlunkError,\n)\n Decode the raw response into a `SendTransactionalEmailResponse` type wrapped in a `Result` type that can be pattern matched on.\nSynonyms:\nplunk/transactional.decode\nplunk/transactional decode","url":"plunk/transactional.html#decode"},{"doc":"plunk/transactional","title":"send","content":"pub fn send(instance: Instance, mail mail: TransactionalEmail) -&gt; Request(\n  String,\n)\n\n Send a transactional email\n\n # Example\n\n \n import gleam/option.{None}\n import gleam/hackney\n import plunk\n import plunk/transactional.{Single, TransactionalEmail}\n\n fn main() {\n   let instance = plunk.new(key: &quot;YOUR_API_KEY&quot;)\n\n   let req =\n     instance\n     |&gt; transactional.send(\n       mail: TransactionalEmail(\n         to: Address(&quot;someone@example.com&quot;),\n         subject: &quot;Hello&quot;,\n         body: &quot;&lt;h1&gt;Hello, World!&lt;/h1&gt;&quot;,\n         name: None,\n         from: None,\n       )\n     )\n   let assert Ok(resp) = hackney.send(req)\n   let assert Ok(data) = transactional.decode(resp)\n   // do whatever you want with the data\n }\n \nSynonyms:\nplunk/transactional.send\nplunk/transactional send","url":"plunk/transactional.html#send"},{"doc":"plunk/transactional","title":"send_transactional_email_decoder","content":"pub fn send_transactional_email_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(SendTransactionalEmailResponse, List(DecodeError))\n\nSynonyms:\nplunk/transactional.send_transactional_email_decoder\nplunk/transactional send_transactional_email_decoder","url":"plunk/transactional.html#send_transactional_email_decoder"},{"doc":"plunk/transactional","title":"plunk/transactional","content":"","url":"plunk/transactional.html"},{"doc":"plunk","title":"decode","content":"pub fn decode(res: Response(String), decoder: fn() -&gt;\n    fn(Dynamic) -&gt; Result(a, List(DecodeError))) -&gt; Result(\n  a,\n  PlunkError,\n)\n\nSynonyms:\nplunk.decode\nplunk decode","url":"plunk.html#decode"},{"doc":"plunk","title":"new","content":"pub fn new(key api_key: String) -&gt; Instance\n\nSynonyms:\nplunk.new\nplunk new","url":"plunk.html#new"},{"doc":"plunk","title":"plunk","content":"","url":"plunk.html"},{"doc":"plunk/contacts","title":"Action","content":"pub type Action =\n  definitions.Action\n\n\nSynonyms:\nplunk/contacts.Action\nplunk/contacts Action","url":"plunk/contacts.html#Action"},{"doc":"plunk/contacts","title":"ActionResult","content":"pub type ActionResult {\n  GetContactResult(ExtendedContact)\n  ListContactsResult(List(Contact))\n  CountContactsResult(Count)\n  CreateContactResult(CreatedContact)\n  SubscriptionResult(Subscription)\n  DeleteContactResult(DeletedContact)\n}\n\nGetContactResult(ExtendedContact)\n\n\nListContactsResult(List(Contact))\n\n\nCountContactsResult(Count)\n\n\nCreateContactResult(CreatedContact)\n\n\nSubscriptionResult(Subscription)\n\n\nDeleteContactResult(DeletedContact)\n\n\nSynonyms:\nplunk/contacts.ActionResult\nplunk/contacts ActionResult","url":"plunk/contacts.html#ActionResult"},{"doc":"plunk/contacts","title":"Contact","content":"pub type Contact =\n  definitions.Contact\n\n\nSynonyms:\nplunk/contacts.Contact\nplunk/contacts Contact","url":"plunk/contacts.html#Contact"},{"doc":"plunk/contacts","title":"Count","content":"pub type Count =\n  definitions.Count\n\n\nSynonyms:\nplunk/contacts.Count\nplunk/contacts Count","url":"plunk/contacts.html#Count"},{"doc":"plunk/contacts","title":"CreateContactData","content":"pub type CreateContactData {\n  CreateContactData(\n    email: String,\n    subscribed: Bool,\n    data: Option(List(#(String, String))),\n  )\n}\n\nCreateContactData(\n  email: String,\n  subscribed: Bool,\n  data: Option(List(#(String, String))),\n)\n\n\nSynonyms:\nplunk/contacts.CreateContactData\nplunk/contacts CreateContactData","url":"plunk/contacts.html#CreateContactData"},{"doc":"plunk/contacts","title":"CreatedContact","content":"pub type CreatedContact =\n  definitions.CreatedContact\n\n\nSynonyms:\nplunk/contacts.CreatedContact\nplunk/contacts CreatedContact","url":"plunk/contacts.html#CreatedContact"},{"doc":"plunk/contacts","title":"DeletedContact","content":"pub type DeletedContact =\n  definitions.DeletedContact\n\n\nSynonyms:\nplunk/contacts.DeletedContact\nplunk/contacts DeletedContact","url":"plunk/contacts.html#DeletedContact"},{"doc":"plunk/contacts","title":"Email","content":"pub type Email =\n  definitions.Email\n\n\nSynonyms:\nplunk/contacts.Email\nplunk/contacts Email","url":"plunk/contacts.html#Email"},{"doc":"plunk/contacts","title":"Event","content":"pub type Event =\n  definitions.Event\n\n\nSynonyms:\nplunk/contacts.Event\nplunk/contacts Event","url":"plunk/contacts.html#Event"},{"doc":"plunk/contacts","title":"ExtendedContact","content":"pub type ExtendedContact =\n  definitions.ExtendedContact\n\n\nSynonyms:\nplunk/contacts.ExtendedContact\nplunk/contacts ExtendedContact","url":"plunk/contacts.html#ExtendedContact"},{"doc":"plunk/contacts","title":"For","content":"pub type For {\n  GetContact\n  ListContacts\n  CountContacts\n  CreateContact\n  Subscribe\n  Unsubscribe\n  DeleteContact\n}\n\nGetContact\n\n\nListContacts\n\n\nCountContacts\n\n\nCreateContact\n\n\nSubscribe\n\n\nUnsubscribe\n\n\nDeleteContact\n\n\nSynonyms:\nplunk/contacts.For\nplunk/contacts For","url":"plunk/contacts.html#For"},{"doc":"plunk/contacts","title":"Subscription","content":"pub type Subscription =\n  definitions.Subscription\n\n\nSynonyms:\nplunk/contacts.Subscription\nplunk/contacts Subscription","url":"plunk/contacts.html#Subscription"},{"doc":"plunk/contacts","title":"SubscriptionData","content":"pub type SubscriptionData {\n  Subscription(id: String)\n}\n\nSubscription(id: String)\n\n\nSynonyms:\nplunk/contacts.SubscriptionData\nplunk/contacts SubscriptionData","url":"plunk/contacts.html#SubscriptionData"},{"doc":"plunk/contacts","title":"Trigger","content":"pub type Trigger =\n  definitions.Trigger\n\n\nSynonyms:\nplunk/contacts.Trigger\nplunk/contacts Trigger","url":"plunk/contacts.html#Trigger"},{"doc":"plunk/contacts","title":"count","content":"pub fn count(instance: Instance) -&gt; Request(String)\n Get count of all contacts\nSynonyms:\nplunk/contacts.count\nplunk/contacts count","url":"plunk/contacts.html#count"},{"doc":"plunk/contacts","title":"create","content":"pub fn create(instance: Instance, contact: CreateContactData) -&gt; Request(\n  String,\n)\n Create a contact\nSynonyms:\nplunk/contacts.create\nplunk/contacts create","url":"plunk/contacts.html#create"},{"doc":"plunk/contacts","title":"decode","content":"pub fn decode(res: Response(String), for for: For) -&gt; Result(\n  ActionResult,\n  PlunkError,\n)\n\n This function decodes all the responses related to this resource albeit a bit differently from the other `decode` functions (but, still type-safe)\n\n # Example\n\n \n import gleam/io\n import gleam/hackney\n import plunk\n import plunk/contacts.{GetContact, GetContactResult}\n\n fn main() {\n   let instance = plunk.new(&quot;API_KEY&quot;)\n   let req = contacts.get(instance, &quot;some-uuid-for-your-contact&quot;)\n   let assert Ok(resp) = hackney.send(req)\n   let assert Ok(data) = contacts.decode(resp, for: GetContact)\n   let assert GetContactResult(contact) = data\n   io.println(contact.id)\n }\n \n\nSynonyms:\nplunk/contacts.decode\nplunk/contacts decode","url":"plunk/contacts.html#decode"},{"doc":"plunk/contacts","title":"delete","content":"pub fn delete(instance: Instance, id: String) -&gt; Request(String)\n Delete a contact\nSynonyms:\nplunk/contacts.delete\nplunk/contacts delete","url":"plunk/contacts.html#delete"},{"doc":"plunk/contacts","title":"get","content":"pub fn get(instance: Instance, id contact_id: String) -&gt; Request(\n  String,\n)\n Get a contact by ID\nSynonyms:\nplunk/contacts.get\nplunk/contacts get","url":"plunk/contacts.html#get"},{"doc":"plunk/contacts","title":"list","content":"pub fn list(instance: Instance) -&gt; Request(String)\n Get all contacts\nSynonyms:\nplunk/contacts.list\nplunk/contacts list","url":"plunk/contacts.html#list"},{"doc":"plunk/contacts","title":"subscribe","content":"pub fn subscribe(instance: Instance, id: String) -&gt; Request(\n  String,\n)\n Subscribe a contact\nSynonyms:\nplunk/contacts.subscribe\nplunk/contacts subscribe","url":"plunk/contacts.html#subscribe"},{"doc":"plunk/contacts","title":"unsubscribe","content":"pub fn unsubscribe(instance: Instance, id: String) -&gt; Request(\n  String,\n)\n Unsubscribe a contact\nSynonyms:\nplunk/contacts.unsubscribe\nplunk/contacts unsubscribe","url":"plunk/contacts.html#unsubscribe"},{"doc":"plunk/contacts","title":"plunk/contacts","content":"","url":"plunk/contacts.html"},{"doc":"plunk/event","title":"Event","content":"pub type Event {\n  Event(\n    event: String,\n    email: String,\n    data: List(#(String, Json)),\n  )\n}\n Event is a type that represents a Plunk event.\nEvent(event: String, email: String, data: List(#(String, Json)))\n\n\nSynonyms:\nplunk/event.Event\nplunk/event Event","url":"plunk/event.html#Event"},{"doc":"plunk/event","title":"TrackEventResponse","content":"pub type TrackEventResponse {\n  TrackEventResponse(\n    success: Bool,\n    contact: String,\n    event: String,\n    timestamp: Option(String),\n  )\n}\n EventResponse is a type that represents a Plunk event response (track event)\nTrackEventResponse(\n  success: Bool,\n  contact: String,\n  event: String,\n  timestamp: Option(String),\n)\n\n\nSynonyms:\nplunk/event.TrackEventResponse\nplunk/event TrackEventResponse","url":"plunk/event.html#TrackEventResponse"},{"doc":"plunk/event","title":"decode","content":"pub fn decode(res: Response(String)) -&gt; Result(\n  TrackEventResponse,\n  PlunkError,\n)\n Decode the raw response into a `TrackEventResponse` type wrapped in a `Result` type that can be pattern matched on.\nSynonyms:\nplunk/event.decode\nplunk/event decode","url":"plunk/event.html#decode"},{"doc":"plunk/event","title":"track","content":"pub fn track(instance: Instance, event event: Event) -&gt; Request(\n  String,\n)\n Track events in your application and send them to Plunk. This function returns a Gleam `Request` type that can then be used with any client of your choice.\n\n # Example\n\n In this example we use the `hackney` HTTP client to send the request we get from `track`:\n\n \n import gleam/json\n import gleam/hackney\n import plunk\n import plunk/event\n\n fn main() {\n   let instance = plunk.new(key: &quot;YOUR_API_KEY&quot;) /\n   let req =\n     instance\n     |&gt; event.track(Event(\n       event: &quot;your-event&quot;,\n       email: &quot;someone@example.com&quot;,\n        data: [#(&quot;name&quot;, json.string(&quot;John&quot;))],\n      ))\n\n   // In a real project, you want to pattern match on the result of `track` to handle errors instead of using `assert Ok(..)`.\n   let assert Ok(resp) = hackney.send(req)\n   let assert Ok(data) = event.decode(resp)\n   // do whatever you want with the data\n }\n \n\nSynonyms:\nplunk/event.track\nplunk/event track","url":"plunk/event.html#track"},{"doc":"plunk/event","title":"track_event_response_decoder","content":"pub fn track_event_response_decoder() -&gt; fn(Dynamic) -&gt;\n  Result(TrackEventResponse, List(DecodeError))\n\nSynonyms:\nplunk/event.track_event_response_decoder\nplunk/event track_event_response_decoder","url":"plunk/event.html#track_event_response_decoder"},{"doc":"plunk/event","title":"plunk/event","content":"","url":"plunk/event.html"}]);